eq.data<- read.csv(file="C:/Users/000110888/Desktop/earthquakedata2010-2020.csv", 
header=TRUE, sep=",")

#creating date-time variable
eq.data$datetime<- as.POSIXct(paste(as.Date(eq.data$DATE), eq.data$TIME))

#computing lag
eq.data$datetime.lag<- c(0,head(eq.data$datetime, -1))

#removing first row
eq.data<-eq.data[-1,] 

#computing interarrival times (in hours)
eq.data$elapsed.time<- (as.numeric(eq.data$datetime)-as.numeric(eq.data$datetime.lag))/3600

#removing interarrival times under one hour
eq.data<- eq.data[eq.data$elapsed.time>1,] 

#creating year-month variable 
eq.data$year.month<- format(as.Date(eq.data$DATE), "%Y-%m")

#creating unique year-month and number of earthquakes per month
freq.month<- data.frame(table(eq.data$year.month))
year.month.unique<-freq.month[,1]
neq.month<- freq.month[,2]

#removing outlier (July, 2019, 107th entry)
year.month.unique<- year.month.unique[-107]
neq.month<- neq.month[-107]

#computing number of days per month
library(lubridate)
day1.month <- ymd(paste(year.month.unique,"01", sep="-") )
library(Hmisc)
ndays.month<- monthDays(as.Date(day1.month, "%Y-%m-%d"))

#estimating intensity rate of earthquakes per day
lambda<- neq.month/ndays.month

#computing cumulative number of days until median day of each month
median.time<- c()
ndays.total<- c()
median.time[1]<- ndays.month[1]/2
ndays.total[1]<- ndays.month[1]

for (i in 2:length(ndays.month)) {
  median.time[i]<-ndays.total[i-1]+ndays.month[i]/2
  ndays.total[i]<- ndays.total[i-1]+ndays.month[i]
}

#plotting lambda against median time
plot(median.time, lambda)

#regressing lambda on median.time
median.time.re<- median.time/1000
median.time.sq<- median.time.re^2
median.time.cu<- median.time.re^3
median.time.qd<- median.time.re^4

glm(lambda ~ median.time.re + median.time.sq + median.time.cu + median.time.qd)

#adding fitted line 
lambda.fn<- function(t) {1.11674-1.75263*(t/1000)+1.41060*(t/1000)^2-0.49950*(t/1000)^3+0.06504*(t/1000)^4}

lines(median.time, lambda.fn(median.time), lwd=2, col="blue")

#conducting goodness-of-fit test

#binning times
time.binned<- as.factor(ifelse(as.Date(eq.data$DATE)<"2011/10/07","1", 
ifelse(as.Date(eq.data$DATE)>="2011/10/07" & as.Date(eq.data$DATE)<"2012/11/10","2",
ifelse(as.Date(eq.data$DATE)>="2012/11/10" & as.Date(eq.data$DATE)<"2013/12/15","3",
ifelse(as.Date(eq.data$DATE)>="2013/12/15" & as.Date(eq.data$DATE)<"2015/01/19","4",
ifelse(as.Date(eq.data$DATE)>="2015/01/19" & as.Date(eq.data$DATE)<"2016/02/23","5",
ifelse(as.Date(eq.data$DATE)>="2016/02/23" & as.Date(eq.data$DATE)<"2017/03/29","6",
ifelse(as.Date(eq.data$DATE)>="2017/03/29" & as.Date(eq.data$DATE)<"2018/05/03","7",
ifelse(as.Date(eq.data$DATE)>="2018/05/03" & as.Date(eq.data$DATE)<"2019/06/07", "8", "9")))))))))

#computing observed frequencies
obs<- table((time.binned))

#computing expected frequencies
exp<- c()
exp[1]<- integrate(lambda.fn, 0, 400)$value
exp[2]<- integrate(lambda.fn, 400, 800)$value
exp[3]<- integrate(lambda.fn, 800, 1200)$value
exp[4]<- integrate(lambda.fn, 1200, 1600)$value
exp[5]<- integrate(lambda.fn, 1600, 2000)$value
exp[6]<- integrate(lambda.fn, 2000, 2400)$value
exp[7]<- integrate(lambda.fn, 2400, 2800)$value
exp[8]<- integrate(lambda.fn, 2800, 3200)$value
exp[9]<- sum(obs)-sum(exp)

obs
round(exp,1)

#computing chi-squared statistic 
print(chi.sq<- sum((obs-exp)^2/exp))

#computing p-value
print(p.value<- 1-pchisq(chi.sq, df=3))

###########################################

int1<- eq.data$elapsed.time[as.Date(eq.data$DATE)<"2011/10/07"]
hist(int1, main="", xlab="", ylab="", col="sky blue")

int2<- eq.data$elapsed.time[as.Date(eq.data$DATE)>="2011/10/07" & as.Date(eq.data$DATE)<"2012/11/10"]
hist(int2, main="", xlab="", ylab="", col="sky blue")

int3<- eq.data$elapsed.time[as.Date(eq.data$DATE)>="2012/11/10" & as.Date(eq.data$DATE)<"2013/12/15"]
hist(int3, main="", xlab="", ylab="", col="sky blue")

int4<- eq.data$elapsed.time[as.Date(eq.data$DATE)>="2013/12/15" & as.Date(eq.data$DATE)<"2015/01/19"]
hist(int4, main="", xlab="", ylab="", col="sky blue")

int5<- eq.data$elapsed.time[as.Date(eq.data$DATE)>="2015/01/19" & as.Date(eq.data$DATE)<"2016/02/23"]
hist(int5, main="", xlab="", ylab="", col="sky blue")
             
int6<- eq.data$elapsed.time[as.Date(eq.data$DATE)>="2016/02/23" & as.Date(eq.data$DATE)<"2017/03/29"]
hist(int6, main="", xlab="", ylab="", col="sky blue")
        
int7<- eq.data$elapsed.time[as.Date(eq.data$DATE)>="2017/03/29" & as.Date(eq.data$DATE)<"2018/05/03"]
hist(int7, main="", xlab="", ylab="", col="sky blue")    

int8<- eq.data$elapsed.time[as.Date(eq.data$DATE)>="2018/05/03" & as.Date(eq.data$DATE)<"2019/06/07"]
hist(int8, main="", xlab="", ylab="", col="sky blue") 

int9<- eq.data$elapsed.time[as.Date(eq.data$DATE)>="2019/06/07"]
hist(int9, main="", xlab="", ylab="", col="sky blue") 
                    
                                        
