stock.data<- read.csv(file="C:/Users/000110888/Desktop/AMZN.csv", 
header=TRUE, sep=",")

date<- as.POSIXct(stock.data$Date)
price<- stock.data$Close

#plotting stock price against date
plot(date, price, type="l", lwd=2, cex=0, col="blue", xlab="Time", 
ylab="Stock price", first.panel=grid())

#calculating increments of log-price
log.inc<- c() 

price1<- price[-1]
price1.lag<- head(price, -1)
log.ratio<- log(price1/price1.lag)

#plotting histogram
library(rcompanion)
plotNormalHistogram(log.ratio, xlab="Log-price increments", col="light blue")

#estimating parameters
print(mu.hat<- mean(log.ratio))
print(sigma.hat<- sd(log.ratio))

#specifying Brownian motion as vector
BM<- c()

#specifying initial value
BM[1]<- 0

#specifying seed
set.seed(43567347)

#simulating Brownian motion with drift and volatility
for (i in 2:377) 
  BM[i]<- mu.hat+BM[i-1] + sigma.hat*rnorm(1)

#computing values for geometric Brownian motion
  GBM<-price[1]*exp(BM)
  
#plotting actual and simulated trajectories
plot(date, price, type="l", lty=1, lwd=2, col="blue", ylim=range(cbind(price, GBM)),
xlab="Time", ylab="Stock price", first.panel=grid())
lines(date, GBM, lwd=2, col="green")
legend("bottomright", c("Actual price", "Simulated price"), lty=1, 
col=c("blue", "green"))

